local VERSION = tonumber(("$Revision: 43083 $"):match("%d+"))

Parrot = AceLibrary("AceAddon-2.0"):new("AceDB-2.0", "AceEvent-2.0", "AceConsole-2.0", "FuBarPlugin-2.0", "Parser-3.0", "AceModuleCore-2.0")
local Parrot, self = Parrot, Parrot
Parrot.version = "r" .. VERSION
Parrot.revision = VERSION
Parrot.date = ("$Date: 2007-07-07 15:21:51 -0400 (Sat, 07 Jul 2007) $"):match("%d%d%d%d%-%d%d%-%d%d")

local waterfall = AceLibrary:HasInstance("Waterfall-1.0") and AceLibrary("Waterfall-1.0")

local _G = _G

local localeTables = {}
function Parrot:L(name, defaultTable)
	if not localeTables[name] then
		localeTables[name] = setmetatable(defaultTable or {}, {__index = function(self, key)
			self[key] = key
			return key
		end})
	end
	return localeTables[name]
end

local L = Parrot:L("Parrot")

local SharedMedia = AceLibrary("SharedMedia-1.0")

Parrot:RegisterDB("ParrotDB")
Parrot:RegisterDefaults('profile', {
	font = "Friz Quadrata TT",
	fontSize = 20,
})

-- FuBar configuration
Parrot.hasIcon = [[Interface\Icons\Spell_Nature_ForceOfNature]]
Parrot.hideWithoutStandby = true
Parrot.defaultPosition = "MINIMAP"
Parrot.defaultMinimapPosition = 250
Parrot.hasNoText = true
Parrot.hasNoColor = true
Parrot.cannotDetachTooltip = true
Parrot.independentProfile = true
Parrot.blizzardTooltip = true

local new, del, newHash, newSet, deepCopy, deepDel
do
	local list = setmetatable({}, {__mode='k'})
	function new(...)
		local t = next(list)
		if t then
			list[t] = nil
			for i = 1, select('#', ...) do
				t[i] = select(i, ...)
			end
			return t
		else
			return { ... }
		end
	end
	
	function newHash(...)
		local t = next(list)
		if t then
			list[t] = nil
		else
			t = {}
		end
		for i = 1, select('#', ...), 2 do
			t[select(i, ...)] = select(i+1, ...)
		end
		return t
	end
	
	function newSet(...)
		local t = next(list)
		if t then
			list[t] = nil
		else
			t = {}
		end
		for i = 1, select('#', ...) do
			t[select(i, ...)] = true
		end
		return t
	end
	
	function del(t)
		for k in pairs(t) do
			t[k] = nil
		end
		t[''] = true
		t[''] = nil
		list[t] = true
		return nil
	end
	
	function deepCopy(from)
		if type(from) ~= "table" then
			return from
		end
		local to = new()
		for k,v in pairs(from) do
			to[k] = deepCopy(v)
		end
		return to
	end

	function deepDel(t)
		if type(t) ~= "table" then
			return nil
		end
		for k,v in pairs(t) do
			t[k] = deepDel(v)
		end
		return del(t)
	end
end
Parrot.new = new
Parrot.newHash = newHash
Parrot.newSet = newSet
Parrot.del = del
Parrot.deepCopy = deepCopy
Parrot.deepDel = deepDel

function Parrot:OnInitialize()
	self:RegisterChatCommand('/Parrot', '/Par', {
		type = 'execute',
		func = function()
			self:OpenMenu()
		end
	})
end

local ParrotFrame

function Parrot:OnEnable()
	if not ParrotFrame then
		ParrotFrame = CreateFrame("Frame", "ParrotFrame", UIParent)
		ParrotFrame:SetFrameStrata("HIGH")
		ParrotFrame:SetToplevel(true)
		ParrotFrame:SetPoint("CENTER")
		ParrotFrame:SetWidth(0.0001)
		ParrotFrame:SetHeight(0.0001)
	end
end

function Parrot:OnDisable()
end

function Parrot:OnClick()
	if waterfall then
		waterfall:Open("Parrot")
	else
		self:Print(L["Waterfall-1.0 is required to access the GUI."])
	end
end

local animationStyles = {
}
local animationStylesCleanup = {
}
local animationStylesValidate = {
}
function Parrot:RegisterAnimationStyle(name, localName, func, cleanup)
	AceLibrary.argCheck(self, name, 2, "string")
	AceLibrary.argCheck(self, localName, 3, "string")
	AceLibrary.argCheck(self, func, 4, "function")
	AceLibrary.argCheck(self, cleanup, 5, "function", "nil")
	if animationStyles[name] then
		error(("Animation style %q already registered"):format(name), 2)
	end
	animationStyles[name] = func
	animationStylesValidate[name] = localName
	animationStylesCleanup[name] = cleanup
end

local scrollAreas = {
	["Notification"] = {
		align = "CENTER",
		animationStyle = "Straight",
		stickyAnimationStyle = "Pow",
		reverse = false,
		height = 150,
		xOffset = 0,
		yOffset = 100,
	},
	["Incoming"] = {
		align = "RIGHT",
		animationStyle = "Left parabola",
		stickyAnimationStyle = "Pow",
		reverse = true,
		height = 260,
		xOffset = -60,
		yOffset = -160,
	},
	["Outgoing"] = {
		align = "LEFT",
		animationStyle = "Right parabola",
		stickyAnimationStyle = "Pow",
		reverse = true,
		height = 260,
		xOffset = 60,
		yOffset = -160,
	},
}

local freeFontStrings = {}
local wildFontStrings = {}
local fontString_num = 0
function Parrot:ShowMessage(text, scrollArea, sticky, color)
	if not self:IsActive() then
		return
	end
	if scrollArea == nil and sticky == nil then
		sticky = true
	end
	if not scrollAreas[scrollArea] then
		if scrollAreas["Notification"] then
			scrollArea = "Notification"
		else
			scrollArea = next(scrollAreas)
			if not scrollArea then
				return
			end
		end
	end
	local fs = next(freeFontStrings)
	if fs then
		fs:SetAlpha(1)
		fs:ClearAllPoints()
		freeFontStrings[fs] = nil
	else
		fontString_num = fontString_num + 1
		fs = ParrotFrame:CreateFontString("ParrotFrameFontString" .. fontString_num, "ARTWORK", "MasterFont")
	end
	
	fs:SetFont(SharedMedia:Fetch('font', self.db.profile.font), self.db.profile.fontSize)
	if color then
		fs:SetTextColor(unpack(color))
	else
		fs:SetTextColor(1, 1, 1)
	end
	fs:SetText(text)
	fs.start = GetTime()
	fs.length = 3
	scrollArea = scrollAreas[scrollArea]
	fs.scrollArea = scrollArea
	local animationStyle
	if sticky then
		animationStyle = scrollArea.stickyAnimationStyle
	else
		animationStyle = scrollArea.animationStyle
	end
	local func = animationStyles[animationStyle]
	local cleanup
	if func then
		cleanup = animationStylesCleanup[animationStyle]
	else
		func = animationStyles.Straight
		cleanup = animationStylesCleanup.Straight
	end
	fs.animationStyle = func
	fs.animationStyleCleanup = cleanup
	fs:SetPoint("BOTTOM", 0, 0)
	wildFontStrings[#wildFontStrings+1] = fs
	fs:Hide()
	
	self:ScheduleRepeatingEvent("Parrot_OnUpdate", self.OnUpdate, 0, self)
end

function Parrot.modulePrototype:ShowMessage(text, position)
	Parrot:ShowMessage(text, position)
end

function Parrot:OnUpdate()
	local now = GetTime()
	local nums = new()
	local maxNums = new()
	local i = 0
	while true do
		i = i + 1
		local fs = wildFontStrings[i]
		if not fs then
			break
		end
		local start, length = fs.start, fs.length
		if start + length <= now then
			local scrollArea = fs.scrollArea
			if scrollArea then
				local cleanup = scrollArea.animationStyleCleanup
				if cleanup then
					cleanup(fs, scrollArea)
				end
			end
			fs:Hide()
			table.remove(wildFontStrings, i)
			i = i - 1
			freeFontStrings[fs] = true
		else
			fs:Show()
			local scrollArea, animationStyle = fs.scrollArea, fs.animationStyle
			if scrollArea then
				if not nums[scrollArea] then
					nums[scrollArea] = new()
					maxNums[scrollArea] = new()
				end
				local value = maxNums[scrollArea][animationStyle]
				if value then
					maxNums[scrollArea][animationStyle] = value + 1
				else
					maxNums[scrollArea][animationStyle] = 1
					nums[scrollArea][animationStyle] = 0
				end
			end
		end
	end
	for _,fs in ipairs(wildFontStrings) do
		local start, length = fs.start, fs.length
		local percent = (now - start) / length
		if percent >= 0.75 then
			fs:SetAlpha((1-percent) * 4)
		end
		
		local scrollArea = fs.scrollArea
		if scrollArea then
			local func = fs.animationStyle
			local num = nums[scrollArea][func] + 1
			nums[scrollArea][func] = num
			fs:ClearAllPoints()
			func(fs, scrollArea, percent, num, maxNums[scrollArea][func])
		end
	end
	for k,v in pairs(maxNums) do
		del(v)
		del(nums[k])
	end
	maxNums = del(maxNums)
	nums = del(nums)
	if not wildFontStrings[1] then
		self:CancelScheduledEvent("Parrot_OnUpdate")
	end
end

Parrot.options = {
	type = 'group',
	handler = Parrot,
	args = {
	}
}

if waterfall then
	waterfall:Register("Parrot", 
						"aceOptions", Parrot.options,
						"title", L["Parrot Configuration"],
						"treeLevels", 5);
end

Parrot.OnMenuRequest = Parrot.options

function Parrot:OnTooltipUpdate()
	GameTooltip:AddLine("Parrot")
	GameTooltip:AddLine(" ")
	if waterfall then
		GameTooltip:AddLine(L["|cffffff00Left-Click|r to change settings with a nice GUI configuration."], 0.2, 1, 0.2)
	end
	GameTooltip:AddLine(L["|cffffff00Right-Click|r to change settings with a drop-down menu."], 0.2, 1, 0.2)
end
